@@ -642,6 +642,7 @@ class QueryBuilder(Selectable, Term):
     SECONDARY_QUOTE_CHAR = "'"
     ALIAS_QUOTE_CHAR = None
     QUERY_ALIAS_QUOTE_CHAR = None
+    QUERY_CLS = Query
 
     def __init__(
         self,
@@ -986,12 +987,21 @@ class QueryBuilder(Selectable, Term):
     def left_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
         return self.join(item, JoinType.left)
 
+    def left_outer_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
+        return self.join(item, JoinType.left_outer)
+
     def right_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
         return self.join(item, JoinType.right)
 
+    def right_outer_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
+        return self.join(item, JoinType.right_outer)
+
     def outer_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
         return self.join(item, JoinType.outer)
 
+    def full_outer_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
+        return self.join(item, JoinType.full_outer)
+
     def cross_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
         return self.join(item, JoinType.cross)
 
@@ -1648,6 +1658,7 @@ class CreateQueryBuilder:
     QUOTE_CHAR = '"'
     SECONDARY_QUOTE_CHAR = "'"
     ALIAS_QUOTE_CHAR = None
+    QUERY_CLS = Query
 
     def __init__(self, dialect: Optional[Dialects] = None) -> None:
         self._create_table = None
@@ -1924,6 +1935,7 @@ class DropQueryBuilder:
     QUOTE_CHAR = '"'
     SECONDARY_QUOTE_CHAR = "'"
     ALIAS_QUOTE_CHAR = None
+    QUERY_CLS = Query
 
     def __init__(self, dialect: Optional[Dialects] = None) -> None:
         self._drop_table = None
